durationtools.yield_all_positive_integer_pairs_in_cantor_diagonalized_order
===========================================================================

.. autofunction:: abjad.tools.durationtools.yield_all_positive_integer_pairs_in_cantor_diagonalized_order.yield_all_positive_integer_pairs_in_cantor_diagonalized_order
